@@ -180,7 +180,10 @@ void MotorPID_InternalEventHandler(uint16_t Event)
  */
 uint16_t MotorPID_GetLastEvent(void)
 {
-  return MotorPID_EventVal;
+  uint16_t LastEventVal = MotorPID_EventVal;
+  
+  MotorPID_EventVal = MotorPID_EventInvalid;
+  return LastEventVal;
 }
 
 // Initialisierung der Motorregelung
@@ -440,6 +443,7 @@ void MotorPID_Start(int8_t Speed, int8_t Steering, uint8_t WayCm)
   {
     // Eventfunktion mit Startevent aufrufen
     SystemTimer_SchedulerAdd(1, pMotorPID_EventFkt, MotorPID_EventStarted);
+//    pMotorPID_EventFkt(MotorPID_EventStarted);  // Start without timing system
     // Wegstreckenzaehler einstellen, die Strecke wird links gezaehlt
     MotorPID_OdoCount       = MOTORPID_CM_TO_TICKS(WayCm);
 #ifdef MOTORPID_RAM_OPTIMIERT
